package com.akamai.hdcore.samples.utility
{
	import com.gskinner.motion.GTween;
	import com.gskinner.motion.easing.Sine;
	
	import flash.display.StageDisplayState;
	import flash.events.FullScreenEvent;
	import flash.geom.Point;
	import flash.geom.Rectangle;
	import flash.net.NetConnection;
	import flash.net.NetStream;
	import flash.system.Capabilities;
	
	import org.openvideoplayer.components.ui.posterframe.PosterFramePlayButton;
	import org.openvideoplayer.components.ui.shared.event.ControlEvent;
	
	public class BaseMediaPlayerViewPresenter extends BasePresenter
	{
		private static const DEFAULT_BUFFER_SPINNER_LABEL:String = "Buffering";

		protected var view:MediaPlayerView;
		protected var posterFrameButton:PosterFramePlayButton;
		
		public function BaseMediaPlayerViewPresenter(view:MediaPlayerView, netStream:NetStream, netConnection:NetConnection)
		{
			this.view = view;
			super(view.controlBar, netStream, netConnection);
		}
		
		override public function destroy():void 
		{
			view = null;
			super.destroy();
		}
		
		override protected function onStageFullScreen(event:FullScreenEvent):void
		{
			super.onStageFullScreen(event);
			if (view.stage.displayState == StageDisplayState.NORMAL)
			{
				view.exitFullscreen();
			}
		}
		
		override protected function setControlReferences():void
		{
			super.setControlReferences();
			posterFrameButton = view.posterFrameButton;
		}
		
		override protected function addControlBarListeners():void
		{
			super.addControlBarListeners();
			if (posterFrameButton)
			{
				posterFrameButton.addEventListener(ControlEvent.PLAY, onPosterFrameClick);				
			}
		}
		
		override protected function onFullscreenClick(event:ControlEvent):void
		{            
			if (view.stage.displayState == StageDisplayState.NORMAL)
			{
				var w:Number;
				var h:Number;
				
				view.enterFullscreen();
				
				if (Capabilities.screenResolutionX/ Capabilities.screenResolutionY> view.video.videoWidth / view.video.videoHeight)
				{
					h = Capabilities.screenResolutionY;
					w = view.video.videoWidth * h / view.video.videoHeight;
				}
				else
				{
					w = Capabilities.screenResolutionX;
					h = view.video.videoHeight * w / view.video.videoWidth;
				} 
				
				view.video.width = Math.max(w, view.video.videoWidth);
				view.video.height = Math.max(h, view.video.videoHeight);
				view.stage.fullScreenSourceRect = new Rectangle(view.video.x, view.video.y, w, h);
			}
			else
			{
				view.exitFullscreen();
			}
			view.stage.displayState = view.stage.displayState == StageDisplayState.NORMAL ? StageDisplayState.FULL_SCREEN : StageDisplayState.NORMAL;	
		}	
		
		override protected function onPlayClick(event:ControlEvent=null):void
		{
			super.onPlayClick(event);
			hidePosterFrameButton();
		}
		
		protected function hidePosterFrameButton():void
		{
			if (posterFrameButton && posterFrameButton.visible)
			{
				posterFrameButton.visible = false;
			}
		}
		
		protected function displaySpinner(label:String = DEFAULT_BUFFER_SPINNER_LABEL):void
		{	
			if (view.stage.displayState == StageDisplayState.NORMAL)
			{
				with (view.spinnerView)
				{
					alpha = 0
					scaleX = 1
					scaleY = 1;
					visible = true;
					textfield.text = label;
				}
				var tween:GTween = new GTween(view.spinnerView, .2);			
				tween.setValues({alpha:1});
				tween.ease = Sine.easeOut;
			}
		}
		
		protected function hideSpinner():void
		{
			var scaleValue:Number = 1.5;
			var tween:GTween = new GTween(view.spinnerView, .5);			
			tween.setValues({ alpha:0, scaleX:scaleValue, scaleY:scaleValue});
			tween.ease = Sine.easeOut;
			tween.onComplete = onSpinnerFadeOut;			
			view.spinnerView.textfield.text = "";
		}
		
		protected function onSpinnerFadeOut(tween:GTween):void
		{
			tween.target.visible = false;
		}
		
		private function onPosterFrameClick(event:ControlEvent  = null):void
		{
			onPlayClick();
			playPauseButton.currentState = ControlEvent.PLAY;
		}
	}
}
