package com.akamai.hdcore.samples.utility
{
	import org.openvideoplayer.components.ui.controlbar.ControlBar;
	import org.openvideoplayer.components.ui.controlbar.view.DualTimeCodeDisplay;
	import org.openvideoplayer.components.ui.controlbar.view.FlexibleSpacer;
	import org.openvideoplayer.components.ui.controlbar.view.FullscreenButton;
	import org.openvideoplayer.components.ui.controlbar.view.GoLiveButton;
	import org.openvideoplayer.components.ui.controlbar.view.MBRSwitchingToggleButton;
	import org.openvideoplayer.components.ui.controlbar.view.PlayPauseButton;
	import org.openvideoplayer.components.ui.controlbar.view.ScrubBar;
	import org.openvideoplayer.components.ui.controlbar.view.VolumeControl;
	import org.openvideoplayer.components.ui.shared.view.ScrollDownButton;
	import org.openvideoplayer.components.ui.shared.view.ScrollUpButton;

	public class ControlBarFactory
	{
		public static const VOD:String = "vod";
		public static const LIVE:String = "live";
		public static const RTMP_LIVE:String = "rtmpLive";
		public static const RTMP_LIVE_MBR:String = "rtmpLiveMBR";
		public static const DVR:String = "dvr";
		public static const MBR_MANUAL:String = "mbrManual";
		
		private static const SINGLETON_ERROR:String = "ControlBarFactory is a singleton - please use the public getInstance method to get a ref of class";
		
		private static var instance:ControlBarFactory;
		
		public static function getInstance():ControlBarFactory
		{
			instance = (!instance) ? new ControlBarFactory : instance;
			return instance;
		}
		
		public function ControlBarFactory()
		{
			if (instance)
			{
				throw new Error(SINGLETON_ERROR);
			}
		}
		
		public function getControlBarByType(type:String, controlBarFactoryParamsVO:ControlBarFactoryParamsVO = null):ControlBar
		{
			var controlBar:ControlBar = configureController(controlBarFactoryParamsVO);
			switch (type)
			{
				
				case ControlBarFactory.RTMP_LIVE_MBR :
					controlBar.addControls([new PlayPauseButton(), new FlexibleSpacer,  new DualTimeCodeDisplay(), 
											new VolumeControl(), new FullscreenButton(), new MBRSwitchingToggleButton(), 
											new ScrollDownButton(), new ScrollUpButton()]);	
					break;
				case ControlBarFactory.RTMP_LIVE :
					controlBar.addControls([new PlayPauseButton(), new FlexibleSpacer,  new DualTimeCodeDisplay(), 
											new VolumeControl(), new FullscreenButton()]);	
					break;
				case ControlBarFactory.LIVE :
				case ControlBarFactory.DVR :
					controlBar.addControls([new PlayPauseButton(), new ScrubBar(),  new GoLiveButton(), new DualTimeCodeDisplay(), 
											new VolumeControl(), new FullscreenButton()]);					
					break;
				case ControlBarFactory.MBR_MANUAL :
					controlBar.addControls([new PlayPauseButton(), new ScrubBar(), new DualTimeCodeDisplay(), new VolumeControl(), 
											new FullscreenButton(), new MBRSwitchingToggleButton(), new ScrollDownButton(), 
											new ScrollUpButton()]);
					break;
				default :
					controlBar.addControls([new PlayPauseButton(), new ScrubBar(), new DualTimeCodeDisplay(), new VolumeControl(), 
											new FullscreenButton()]);
					break;
			}
			return controlBar;
		}
		
		private function configureController(controlBarFactoryParamsVO:ControlBarFactoryParamsVO):ControlBar
		{
			var controlBar:ControlBar = new ControlBar();
			var vo:ControlBarFactoryParamsVO = controlBarFactoryParamsVO == null ? new ControlBarFactoryParamsVO() : controlBarFactoryParamsVO;
			
			controlBar.width 						= vo.width;
			controlBar.height 						= vo.height;
			controlBar.controlUpperHighlightColor 	= vo.controlUpperHighlightColor;
			controlBar.controlUpperHighlightAlpha 	= vo.controlUpperHighlightAlpha;
			controlBar.controlBarBackgroundColor 	= vo.controlBarBackgroundColor;
			controlBar.controlBarBackgroundAlpha 	= vo.controlBarBackgroundAlpha;
			controlBar.progressBarColor 			= vo.progressBarColor;
			controlBar.downloadProgressBarColor 	= vo.downloadProgressBarColor;
			controlBar.sliderTrackBackgroundColor 	= vo.sliderTrackBackgroundColor;
			controlBar.strokeColor 					= vo.strokeColor;
			controlBar.strokeAlpha 					= vo.strokeAlpha; 
			controlBar.iconColor 					= vo.iconColor;
			controlBar.iconAlpha 					= vo.iconAlpha;
			
			return controlBar;
		}
	}
}
