package {
	
	import com.akamai.version.HDCoreVersion;
	import com.akamai.player.Controller;
	import com.akamai.player.HDVideoRenderer;
	import com.akamai.player.StatsDisplay;
	import com.akamai.playeranalytics.AnalyticsPluginLoader;
	
	import flash.display.Sprite;
	import flash.display.StageAlign;
	import flash.display.StageDisplayState;
	import flash.display.StageScaleMode;
	import flash.events.Event;
	import flash.events.FullScreenEvent;
	import flash.geom.Rectangle;
	import flash.ui.ContextMenu;
	import flash.ui.ContextMenuItem;

	[SWF(width="640", height="391", frameRate="30", backgroundColor="#111111")]
	public class HDExamplePlayer extends Sprite
	{
		private var renderer:HDVideoRenderer;
		private var controller:Controller;
		private var statsDisplay:StatsDisplay;
		private var src:String;
		private var slate:String;
		private var startTime:Number;
		private var endTime:Number;
		private var bitrateLimit:Number;
		private var ref:String;
		
		private static const TEST_URL:String = "http://mediapm.edgesuite.net/jawyllie/hd-benchmark/earth.smil";	
		private static const VERSION:String = "1.5";
		
		// Add your own Akamai Media Analytics properties here
		private static const ANALYTICS_BEACON:String="";

			
		public function HDExamplePlayer()
		{
			init();
		}
		
		private function init():void
		{

			// Ingest optional flashvars
			src = this.loaderInfo.parameters.src != undefined ? this.loaderInfo.parameters.src.toString():TEST_URL;
			slate = this.loaderInfo.parameters.slate != undefined ? this.loaderInfo.parameters.slate.toString():"";
			bitrateLimit = this.loaderInfo.parameters.bitrateLimit != undefined ? Number(this.loaderInfo.parameters.bitrateLimit.toString()):int.MAX_VALUE;
			startTime = this.loaderInfo.parameters.startTime != undefined ? Number(unescape(this.loaderInfo.parameters.startTime.toString())):NaN;
			endTime = this.loaderInfo.parameters.startTime != undefined ? Number(unescape(this.loaderInfo.parameters.startTime.toString())):NaN;
			ref = this.loaderInfo.parameters.ref != undefined ? this.loaderInfo.parameters.ref.toString():"";
			// Set stage
			this.stage.scaleMode = StageScaleMode.NO_SCALE;
            this.stage.align= StageAlign.TOP_LEFT;
            // Add children
			renderer = new HDVideoRenderer(this.stage.stageWidth,this.stage.stageHeight - 31);
			renderer.ns.maximumBitrateAllowed = bitrateLimit;
			renderer.waitingSlate = slate;
			if (ANALYTICS_BEACON != "")
			{
				renderer.analyticsBeacon = ANALYTICS_BEACON;
				if (ref != "")
				{
					AnalyticsPluginLoader.setData("site", ref);
				}
			}
			addChild(renderer);
			controller = new Controller(this.stage.stageWidth,31);
			controller.addEventListener("fullScreen",onFullScreen);
			controller.addEventListener("normal",onFullScreen);
			controller.addEventListener("showstats",onShowStats);
			controller.addEventListener("waitForStream",onWaitForStream);
			controller.addEventListener("restart",onRestart);
			controller.y=this.stage.stageHeight - 31;
			controller.setNetStream(renderer.ns);
			addChild(controller);
			statsDisplay = new StatsDisplay();
			statsDisplay.x = (this.stage.stageWidth - statsDisplay.width)/2;
			statsDisplay.y = (this.stage.stageHeight - statsDisplay.height)/2;
			statsDisplay.visible = false;
			statsDisplay.alpha = .9;
			statsDisplay.setNetStream(renderer.ns);
			addChild(statsDisplay);
			var myContextMenu:ContextMenu = new ContextMenu();
			myContextMenu.hideBuiltInItems();
			var playerItem:ContextMenuItem = new ContextMenuItem("Player version:" + VERSION);
			var coreItem:ContextMenuItem = new ContextMenuItem("Akamai HDCore version: " + HDCoreVersion.version);
            myContextMenu.customItems.push(playerItem);
            myContextMenu.customItems.push(coreItem);
            this.contextMenu = myContextMenu;
            renderer.debug("src: " + src);
            renderer.debug("slate: " + slate);
            renderer.debug("bitrateLimit: " + bitrateLimit);
            renderer.debug("startTime: " + startTime);
			renderer.debug("endTime: " + endTime);
            renderer.debug("ref: " + ref);
			if (src == "")
			{
				controller.displayError("Error: No src parameter has been specified");
			}
			else
			{
				renderer.load(src,startTime,endTime);
			}
		}

		private function onRestart(event:Event):void
		{
			renderer.load(src,startTime,endTime);
		}
		private function onFullScreen(event:Event):void
			{
				switch(this.stage.displayState)
				{
					case StageDisplayState.NORMAL:
						renderer.setSize(1280,720);
						renderer.ns.maximumBitrateAllowed = int.MAX_VALUE;
						if (!this.stage.hasEventListener(FullScreenEvent.FULL_SCREEN)){
							this.stage.addEventListener(FullScreenEvent.FULL_SCREEN,onFullScreenEvent);
						}
						this.stage.scaleMode = StageScaleMode.NO_BORDER;
						controller.setSize(1280,31);
						controller.y = 720-31;
						addChild(controller);
						statsDisplay.x = (1280 - statsDisplay.width)/2;
						statsDisplay.y = (720 - statsDisplay.height)/2;
						this.stage.fullScreenSourceRect = new Rectangle(0,0,1280,720);
					 	this.stage.displayState = StageDisplayState.FULL_SCREEN;
						break;
					case StageDisplayState.FULL_SCREEN:
						this.stage.displayState = StageDisplayState.NORMAL;
						break;
				}
		}
			
		private function onFullScreenEvent(event:FullScreenEvent):void
		{
			if (!event.fullScreen) {
				this.stage.scaleMode = StageScaleMode.NO_SCALE;
				controller.setSize(this.stage.stageWidth,31);
				controller.y=this.stage.stageHeight-31;
				statsDisplay.x = (this.stage.stageWidth - statsDisplay.width)/2;
				statsDisplay.y = (this.stage.stageHeight-31 - statsDisplay.height)/2;
				renderer.setSize(this.stage.stageWidth,this.stage.stageHeight-31);
				renderer.ns.maximumBitrateAllowed = bitrateLimit;
			}
		}
		private function onShowStats(event:Event):void
		{
			statsDisplay.visible = !statsDisplay.visible;
		}
		private function onWaitForStream(event:Event):void
		{
			renderer.showWaitingSlate();
		}
		

	}
}
